@@ -7,7 +7,7 @@
 #include <QHash>
 #include <QFile>
 #include <QTextStream>
-#include <qwaitcondition.h>
+#include <QMessageBox>
 
 namespace Ui {
     class MainWindow;
@@ -24,6 +24,7 @@ public:
 private:
     Ui::MainWindow *ui;
     QProgressDialog progress;
+    QProgressDialog progress2;
     QColorDialog colors;
     void readdirs();
     void oldfonts();
@@ -33,6 +34,9 @@ private:
     void writeSettings();
 
 private slots:
+    void on_fontimport_triggered();
+    void on_fontdisabled_2_clicked();
+    void on_fontpainted_clicked();
     void on_Snap_editingFinished();
     void on_horizontalSlider_3_valueChanged(int value);
     void on_checkBoxActivate_stateChanged(int );
@@ -46,6 +50,7 @@ private slots:
     void on_horizontalSlider_valueChanged(int);
     void on_pushButton_clicked();
     void processFinished(int exitCode);
+    void process2Finished(int exitCode);
 };
 
 #endif // MAINWINDOW_H
